wccGLLAWMatrix: W Matrix

View source: R/GLLAfunctions.R

wccGLLAWMatrixR Documentation

W Matrix

Description

This function returns a matrix, W, which when premultiplied by a time delay embedded matrix will calculate the time derivatives of the time series in the time delay embedded matrix.

Usage

wccGLLAWMatrix(embed=NA, tau=NA, deltaT=1, order=2)

Arguments

embed

A numeric wholenumber value indicating the embedding dimension, the number of columns in the target time delay embedded matrix. embed must be greater than or equal to order + 1. ‘embed’ must be equal to that given to ‘wccGLLAEmbed’ to create the target time delay embedded matrix.

tau

An numeric wholenumber value indicating the number of samples by which each column in the time delay embedded matrix is lagged. ‘tau’ must be greater than or equal to 1. ‘tau’ must be equal to that given to ‘wccGLLAEmbed’ to create the target time delay embedded matrix.

deltaT

A numeric value indicating the elapsed time between samples in the time series that was time delay embedded. deltaT must be greater than 0.

order

A numeric wholenumber value indicating the highest derivative to be estimated when the W matrix is premultiplied by the time delay embedding matrix.

Details

The W matrix is defined by the Generalized Local Linear Approximation method for calculating derivatives of time series. First time delay embed the time series using ‘wccGLLAEmbed’ . Then call ‘wccGLLAWMatrix’ to return the appropriate W matrix for that embedding. Finally postmultiply the time delay embedding matrix by the W matrix, which creates an output matrix whose rows match the rows of the time delay embedded matrix and whose columns are the calculated derivatives of the time series.

Value

Returns the W matrix that can postmultiply a time delay embedded matrix to calculate derivatives.

References

Boker, S. M., Deboeck, P. R., Edler, C., & Keel, P. K. (2010) Generalized Local Linear Approximation of Derivatives from Time Series. In Statistical Methods for Modeling Human Dynamics: An Interdisciplinary Dialogue, S.-M. Chow & E. Ferrar (Eds). Boca Raton, FL: Taylor & Francis, pp 179–212.

See Also

wccGLLAEmbed for creating a time delay embedding matrix.

Examples

# Create a time delay embedding matrix from a single time series.
theSeries <- sin((1:20)/10)
length(theSeries)
embeddedMatrix <- wccGLLAEmbed(theSeries, embed=4, tau=1, label="x", idColumn=FALSE)
dim(embeddedMatrix)
# Calculate derivatives for the series
embeddedMatrix %*% wccGLLAWMatrix(embed=4, tau=1, deltaT=1, order=2)


wcc documentation built on July 14, 2026, 5:07 p.m.