| wccPeakPick-internal | R Documentation |
Internal helpers used by wccPeakPick. wccSmoothMatrix builds and caches the loess-equivalent smoother matrix for a given column length and pspan; wccPeakSearch scans a smoothed row for a peak given a bounding window. Not intended for direct use.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.